==> zio-aws-s3_2.12-6.20.78.3-sources.jar: zio/aws/s3/model/GetBucketAccelerateConfigurationResponse.scala <==
package zio.aws.s3.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetBucketAccelerateConfigurationResponse(
    status: Optional[zio.aws.s3.model.BucketAccelerateStatus] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.GetBucketAccelerateConfigurationResponse = {
    import GetBucketAccelerateConfigurationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.GetBucketAccelerateConfigurationResponse
      .builder()
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .build()
  }
  def asReadOnly
      : zio.aws.s3.model.GetBucketAccelerateConfigurationResponse.ReadOnly =
    zio.aws.s3.model.GetBucketAccelerateConfigurationResponse
      .wrap(buildAwsValue())
}
object GetBucketAccelerateConfigurationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.GetBucketAccelerateConfigurationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.GetBucketAccelerateConfigurationResponse =
      zio.aws.s3.model
        .GetBucketAccelerateConfigurationResponse(status.map(value => value))
    def status: Optional[zio.aws.s3.model.BucketAccelerateStatus]
    def getStatus: ZIO[Any, AwsError, zio.aws.s3.model.BucketAccelerateStatus] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.GetBucketAccelerateConfigurationResponse
  ) extends zio.aws.s3.model.GetBucketAccelerateConfigurationResponse.ReadOnly {
    override val status: Optional[zio.aws.s3.model.BucketAccelerateStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.s3.model.BucketAccelerateStatus.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.GetBucketAccelerateConfigurationResponse
  ): zio.aws.s3.model.GetBucketAccelerateConfigurationResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-s3_3-5.17.104.2-sources.jar: zio/aws/s3/model/GetBucketAccelerateConfigurationResponse.scala <==
package zio.aws.s3.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetBucketAccelerateConfigurationResponse(
    status: Option[zio.aws.s3.model.BucketAccelerateStatus] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.GetBucketAccelerateConfigurationResponse = {
    import GetBucketAccelerateConfigurationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.GetBucketAccelerateConfigurationResponse
      .builder()
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .build()
  }
  def asReadOnly
      : zio.aws.s3.model.GetBucketAccelerateConfigurationResponse.ReadOnly =
    zio.aws.s3.model.GetBucketAccelerateConfigurationResponse
      .wrap(buildAwsValue())
}
object GetBucketAccelerateConfigurationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.GetBucketAccelerateConfigurationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.GetBucketAccelerateConfigurationResponse =
      zio.aws.s3.model
        .GetBucketAccelerateConfigurationResponse(status.map(value => value))
    def status: Option[zio.aws.s3.model.BucketAccelerateStatus]
    def getStatus: ZIO[Any, AwsError, zio.aws.s3.model.BucketAccelerateStatus] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.GetBucketAccelerateConfigurationResponse
  ) extends zio.aws.s3.model.GetBucketAccelerateConfigurationResponse.ReadOnly {
    override val status: Option[zio.aws.s3.model.BucketAccelerateStatus] = scala
      .Option(impl.status())
      .map(value => zio.aws.s3.model.BucketAccelerateStatus.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.GetBucketAccelerateConfigurationResponse
  ): zio.aws.s3.model.GetBucketAccelerateConfigurationResponse.ReadOnly =
    new Wrapper(impl)
}
